@@ -161,7 +161,7 @@ rx_solving_options *getRxOp(rx_solve *rx);
 SEXP RxODE_df(int doDose, int doTBS);
 SEXP RxODE_par_df();
 
-rx_solving_options_ind *rxOptionsIniEnsure(int mx);
+void rxOptionsIniEnsure(int mx);
 
 void rxUpdateFuns(SEXP trans);
 
